bltest
===========

Testing utilities in Python, such as assert matchers and scratch directories.



Features
--------

* `attr`
* `speed`
* `supress_output`
* `skip_if_ci`
* `skip_if_unavailable`
* `BackupEnvMixin`
* `SuppressLoggingMixin`

And `ExtraAssertionsMixin` with methods

* `assertAlmostEqual`
* `assertDictOfArraysEqual`
* `assertDictOfArraysAlmostEqual`
* `assertTextEqual`
* `assertFilesEqual`
* `assertDerivativeEquals`
* `assertSparseArrayEqual`
